@@ -48,21 +48,27 @@ class Base:
     # ======================상속 클래스에서 재구성할 수 있는 함수들================
     # get 관련함수는 self 를 사용하나 drop 관련 함수를 신중을 위해 self 를 사용하지 않고 반드시 인자로 받는다.
 
-    def get_all_db(self) -> list:
-        return sorted(self.client.list_database_names())
+    @staticmethod
+    def get_all_db() -> list:
+        client = pymongo.MongoClient(load_setting()['mongo'])
+        return sorted(client.list_database_names())
 
-    def drop_all_db(self):
-        pre_db = self.get_all_db()
+    @staticmethod
+    def drop_all_db():
+        client = pymongo.MongoClient(load_setting()['mongo'])
+        pre_db = Base.get_all_db()
         for db in pre_db:
-            self.client.drop_database(db)
-        post_db = self.get_all_db()
+            client.drop_database(db)
+        post_db = Base.get_all_db()
         print(f"Drop all db..{len(pre_db)} -> {len(post_db)}")
 
-    def drop_db(self, db: str):
-        pre_db = self.get_all_db()
+    @staticmethod
+    def drop_db(db: str):
+        client = pymongo.MongoClient(load_setting()['mongo'])
+        pre_db = Base.get_all_db()
         if db in pre_db:
-            self.client.drop_database(db)
-            post_db = self.get_all_db()
+            client.drop_database(db)
+            post_db = Base.get_all_db()
             print(f"Drop {db}..{len(pre_db)} -> {len(post_db)}")
         else:
             raise ValueError(f'Invalid value : {db}')
@@ -223,23 +229,27 @@ class Corps(Base):
 
     # ======================부모 클래스에서 재구성한 함수들================
 
-    def get_all_corps(self) -> list:
+    @staticmethod
+    def get_all_corps() -> list:
         return_list = []
-        for col in super().get_all_db():
+        for col in Base.get_all_db():
             if utils.is_6digit(col):
                 return_list.append(col)
         return sorted(return_list)
 
-    def drop_all_corps(self):
-        pre_db = self.get_all_corps()
+    @staticmethod
+    def drop_all_corps():
+        client = pymongo.MongoClient(load_setting()['mongo'])
+        pre_db = Corps.get_all_corps()
         for db in pre_db:
-            self.client.drop_database(db)
-        post_db = self.get_all_corps()
+            client.drop_database(db)
+        post_db = Corps.get_all_corps()
         print(f"Drop all corps..{len(pre_db)} -> {len(post_db)}")
 
-    def drop_corp(self, code: str):
+    @staticmethod
+    def drop_corp(code: str):
         if utils.is_6digit(code):
-            super().drop_db(db=code)
+            Base.drop_db(db=code)
         else:
             raise ValueError(f'Invalid value : {code}(6 digit)')
 
